% Computes exciton dissociation efficiency for high and low-performing
% devices for various acceptor/[acceptor+donor] compositions (denoted by x)
% as described in [insert citation]. lambda is the wavelength of insterest.
% n_don and n_acc are the refractive indices of the donor and acceptor,
% respectively.
function coeff = diss(x,lambda,n_don,n_acc)

global sim_lambda

%Exciton quenching for high-performing devices
compos = [0 0.5 0.7 0.8333 1]; %acceptor/[acceptor+donor]
quench_acc = [0 0.54 0.77 0.56 0]; %quenching of excitons generated in
% acceptor phase
quench_don = [0 0.15 0.51 0.3 0]; %quenching of excitons generated in
% donor phase

%Exciton quenching for low-performing devices
% compos = [0 0.5 0.666 0.833 1];
% quench_acc = [0 0.485 0.6375 0.4736 0];
% quench_don = [0 0.116 0.225 0.2237 0];

% Determine acceptor and donor exciton quenching for a given
% acceptor/[acceptor+donor] compisition through linear interpolation.
    u = find(compos>=x);
    l = find(compos<=x);
    if u(1)==l(end),
        coeff_acc = quench_acc(u(1));
        coeff_don = quench_don(u(1));
    else
        temp_acceptor = inv([compos(l(end)) 1; compos(u(1)) 1])*[quench_acc(l(end)); quench_acc(u(1))];
        temp_donor = inv([compos(l(end)) 1; compos(u(1)) 1])*[quench_don(l(end)); quench_don(u(1))];
        coeff_acc = (temp_acceptor(1)*x+temp_acceptor(2));
        coeff_don = (temp_donor(1)*x+temp_donor(2));
    end

abs_donor = imag(n_don)';
abs_acceptor = imag(n_acc)';

index = find(lambda==sim_lambda);
absdon = abs_donor(index);
absacc = abs_acceptor(index);

% Normalize quenching efficiency with respect to donor and acceptor
% absorption
coeff = (coeff_acc*(1-10^(-absacc*pos(x)))+coeff_don*(1-10^(-absdon*(1-pos(x)))))/(2-10^(-absacc*pos(x))-10^(-absdon*(1-pos(x))));